@@ -5,6 +5,10 @@ use warnings;
 
 use base qw(Test::Unit::TestCase);
 
+sub set_up {
+    die "Problem with set_up";   
+}
+
 sub tear_down {
     die "Problem with tear_down";
 }
